check_disk_space_composefs

Function check_disk_space_composefs 

pub(crate) fn check_disk_space_composefs(
    cfs: &Repository<Sha512HashValue>,
    manifest: &ImageManifest,
    imgref: &ImageReference,
) -> Result<()>
Verify there is sufficient disk space to pull an image into the composefs store for the native composefs backend (uses a raw ImageManifest).