check_disk_space_unified

Function check_disk_space_unified 

pub(crate) fn check_disk_space_unified(
    cfs: &Repository<Sha512HashValue>,
    image_meta: &PreparedImportMeta,
    imgref: &ImageReference,
) -> Result<()>
Verify there is sufficient disk space to pull an image into the composefs store via the ostree unified-storage path (uses PreparedImportMeta).